#!/usr/bin/env python

import datetime
import sys

import demosat

def get_gps_states(file):
	for state in demosat.get_states(file):
		if state.latitude.value is None:
			continue
		if state.longitude.value is None:
			continue
		if state.altitude.value is None:
			continue
		if (state.latitude.is_current(state.seconds_elapsed) \
		    or state.longitude.is_current(state.seconds_elapsed) \
		    or state.altitude.is_current(state.seconds_elapsed)):
			yield state

use_timestamps = False

if "-t" in sys.argv:
	# Include timestamp placemarks.
	use_timestamps = True

print """\
<?xml version="1.0" encoding="UTF-8"?>
<kml xmlns="http://earth.google.com/kml/2.1">
<Folder>
<Placemark>
  <description>...</description>
  <name>Flight path</name>
  <Style>
    <LineStyle>
      <color>ff00ff00</color>
      <width>4</width>
    </LineStyle>
    <PolyStyle>
      <fill>0</fill>
    </PolyStyle>
  </Style>
  <LineString>
    <altitudeMode>absolute</altitudeMode>
    <coordinates>"""

# states = list(get_second_states(sys.stdin))

states = []

for state in get_gps_states(sys.stdin):
	if state.latitude.value is None or state.longitude.value is None or state.altitude.value is None:
		continue
	print "%f,%f,%f" % (state.longitude.value, state.latitude.value, state.altitude.value)
	states.append(state)

print """\
    </coordinates>
  </LineString>
</Placemark>"""

if use_timestamps:
	print """\
<Folder>
"""
	for state in states:
		print """\
<Placemark>
  <TimeStamp>
    <when>%s</when>
  </TimeStamp>
  <Point>
    <altitudeMode>absolute</altitudeMode>
    <coordinates>%f,%f,%f</coordinates>
  </Point>
</Placemark>""" % (datetime.datetime.combine(state.date, state.time).strftime("%Y-%m-%dT%H:%M:%SZ"), state.longitude.value, state.latitude.value, state.altitude.value)
	print """\
</Folder>
"""

print """\
</Folder>
</kml>"""
