#include <math.h>

#include "fieldsat.h"

static unsigned int s2_seen = 0;

int main(int argc, char *argv[])
{
	struct fieldsat_sample sample;
	struct fieldsat_state state;
	FILE *fp;
	int i;
	char buf[500];
	unsigned long previous_timestamp;
	double t, time, previous_time;

	fp = stream_open(argc, argv);

	state_init(&state);

	previous_timestamp = 0UL;
	previous_time = 0.0;
	time = 0.0;
	while (read_sample(fp, &sample)) {
		if (sample.type == SAMPLE_TYPE_GO && time > 0.0) {
			previous_timestamp = 0UL;
			previous_time = 0.0;
			time = 0.0;
			printf("\n");
		}
		if (sample.type == SAMPLE_TYPE_S2)
			s2_seen = 1;
		t = (double) (sample.timestamp - previous_timestamp) / F_CPU;
		if (time == 0.0) {
			previous_time = t;
			time = t;
			t = 0;
		} else {
			if (t > 1.0) {
				fprintf(stderr, "Warning: t = %f at %02d:%02d:%02.3f %lu %lu.\n", t, (int) (time / 3600), (int) ((fmod(time, 3600)) / 60), fmod(time, 60), previous_timestamp, sample.timestamp);
				break;
			}
			time += t;
		}
		previous_timestamp = sample.timestamp;
		state_update(&state, &sample, t);
		if (time - previous_time > 10) {
			#ifdef TEMPERATURE
			if (s2_seen)
				printf("%f %f\n", time / 3600.0, state.temp_int);
			#endif
			#ifdef LUMINOSITY
			printf("%f %f\n", time / 3600.0, state.solar_luminosity);
			#endif
			#ifdef VOLTAGE
			printf("%f %f\n", time / 3600.0, state.solar_voltage);
			#endif
			fflush(stdout);
			previous_time += 10;
		}
	}

	return 0;
}
