#!/usr/bin/env python

import math
import sys

import demosat

class Stats:
	def __init__(self, name = None):
		self.name = name
		self.count = 0
		self.min = None
		self.max = None
		self.mean = 0
		self.stdev = None

		self.s = 0.0

	def update(self, value):
		self.count += 1
		if self.min is None or value < self.min:
			self.min = value
		if self.max is None or value > self.max:
			self.max = value
		# See # http://en.wikipedia.org/wiki/Algorithms_for_calculating_variance#Algorithm_III
		# or Knuth vol. 2, 4.2.2 for the source of this algorithm.
		delta = value - self.mean
		self.mean += delta / self.count
		self.s += delta * (value - self.mean)
		self.stdev = math.sqrt(self.s / self.count)

	def __str__(self):
		line = ""
		if self.name is not None:
			line += self.name + ": "
		line += "count: %6d min: %+6.2f max: %+6.2f mean: %+6.2f stdev: %.6f" % (self.count, self.min, self.max, self.mean, self.stdev)
		return line

def vector_length(v):
	return math.sqrt(sum(x * x for x in v))

acceleration = [Stats("Acc. X"), Stats("Acc. Y"), Stats("Acc. Z")]
acc_total = Stats("|Acc.|")
angular_velocity = [Stats("Rot. X"), Stats("Rot. Y"), Stats("Rot. Z")]

try:
	for state in demosat.get_states(sys.stdin):
		for i in range(0, 3):
			if state.acceleration[i].is_current(state.seconds_elapsed):
				acceleration[i].update(state.acceleration[i].value)
			if state.angular_velocity[i].is_current(state.seconds_elapsed):
				angular_velocity[i].update(state.angular_velocity[i].value)
		for a in state.acceleration:
			if a.value is None:
				break
		else:
			acc_total.update(vector_length(a.value for a in state.acceleration))

except KeyboardInterrupt:
	pass

for a in acceleration:
	print a
print acc_total
for a in angular_velocity:
	print a
